LuaResult

Enum LuaResult 

pub enum LuaResult {
    Values(Vec<Value>),
    Return(Vec<Value>),
    Break,
}
Result of evaluating a Lua core form.

Variants



Values(Vec<Value>)

Ordinary expression values.



Return(Vec<Value>)

Values carried by a Lua return form.



Break

Non-local exit carried by a Lua break form.

Implementations

Source

impl LuaResult

pub fn one(value: Value) -> Self

Build an ordinary single-value result.

pub fn values(values: Vec<Value>) -> Self

Build ordinary expression values.

pub fn return_values(values: Vec<Value>) -> Self

Build returned values.

pub fn break_signal() -> Self

Build a break result.

pub fn values_ref(&self) -> &[Value]

Borrow the contained values.

pub fn is_return(&self) -> bool

Return whether this result came from a Lua return form.

pub fn is_break(&self) -> bool

Return whether this result came from a Lua break form.

pub fn into_values(self) -> Vec<Value>

Consume the result and return its values.