pub struct LuaEnv { /* private fields */ }Expand description
Lexical local environment used by the Lua core eval policy.
Implementations
Sourceimpl LuaEnv
impl LuaEnv
Sourcepub fn define(&mut self, name: Symbol, value: Value) -> Result<()>
pub fn define(&mut self, name: Symbol, value: Value) -> Result<()>
Bind a Lua local value in the current frame.
Sourcepub fn assign(&mut self, name: &Symbol, value: Value) -> Result<Value>
pub fn assign(&mut self, name: &Symbol, value: Value) -> Result<Value>
Assign an existing Lua local.
Sourcepub fn capture(&self, name: &Symbol) -> Result<BindingCell>
pub fn capture(&self, name: &Symbol) -> Result<BindingCell>
Capture an existing Lua local as a shared upvalue cell.